@@ -11,17 +11,33 @@ typedef Eo Ecore_Con_Eet_Base;
 #ifndef _ECORE_CON_EET_BASE_EO_TYPES
 #define _ECORE_CON_EET_BASE_EO_TYPES
 
+/** Ecore connection reply data structure
+ *
+ * @ingroup Ecore_Con
+ */
+typedef struct _Ecore_Con_Reply Ecore_Con_Reply;
+
 
 #endif
 
+
+
+
+
+
+
 /**
- * @brief Function to register a @ref Eet_Data_Descriptor to the ecore_con_eet
+ * @brief Function to register a @ref Eet.Data.Descriptor to the ecore_con_eet
  * object.
  *
- * @param[in] edd The Eet_Data_Descriptor that is to be registered.
+ * @param[in] obj The object.
+ * @param[in] name The name of the eet stream.
+ * @param[in] edd The Eet.Data.Descriptor that is to be registered.
  *
  * @ingroup Ecore_Con_Eet_Base
  */
 EAPI void ecore_con_eet(Ecore_Con_Eet_Base *obj, const char *name, Eet_Data_Descriptor *edd);
 
+
+
 #endif
