@@ -13,45 +13,54 @@ typedef Eo Efl_Control;
 
 
 #endif
+/** Efl control interface
+ *
+ * @ingroup Efl_Control
+ */
 #define EFL_CONTROL_INTERFACE efl_control_interface_get()
 
-EAPI const Eo_Class *efl_control_interface_get(void) EINA_CONST;
+EWAPI const Efl_Class *efl_control_interface_get(void);
 
 /**
  * @brief Control the priority of the object.
  *
+ * @param[in] obj The object.
  * @param[in] priority The priority of the object
  *
  * @ingroup Efl_Control
  */
-EOAPI void efl_control_priority_set(int priority);
+EOAPI void efl_control_priority_set(Eo *obj, int priority);
 
 /**
  * @brief Control the priority of the object.
  *
+ * @param[in] obj The object.
+ *
  * @return The priority of the object
  *
  * @ingroup Efl_Control
  */
-EOAPI int efl_control_priority_get(void);
+EOAPI int efl_control_priority_get(const Eo *obj);
 
 /**
  * @brief Controls whether the object is suspended or not.
  *
+ * @param[in] obj The object.
  * @param[in] suspend Controls whether the object is suspended or not.
  *
  * @ingroup Efl_Control
  */
-EOAPI void efl_control_suspend_set(Eina_Bool suspend);
+EOAPI void efl_control_suspend_set(Eo *obj, Eina_Bool suspend);
 
 /**
  * @brief Controls whether the object is suspended or not.
  *
+ * @param[in] obj The object.
+ *
  * @return Controls whether the object is suspended or not.
  *
  * @ingroup Efl_Control
  */
-EOAPI Eina_Bool efl_control_suspend_get(void);
-
+EOAPI Eina_Bool efl_control_suspend_get(const Eo *obj);
 
 #endif
