@@ -42,6 +42,7 @@ EWAPI const Efl_Class *efl_gfx_filter_interface_get(void);
  *
  * Set to @c null to disable filtering.
  *
+ * @param[in] obj The object.
  * @param[in] code The Lua program source code.
  * @param[in] name An optional name for this filter.
  *
@@ -55,6 +56,7 @@ EOAPI void efl_gfx_filter_program_set(Eo *obj, const char *code, const char *nam
  * @brief Gets the code of the filter program set on this object. May be
  * @c null.
  *
+ * @param[in] obj The object.
  * @param[out] code The Lua program source code.
  * @param[out] name An optional name for this filter.
  *
@@ -75,6 +77,7 @@ EOAPI void efl_gfx_filter_program_get(const Eo *obj, const char **code, const ch
  * to 1) of that animation timeline. The second state can be omitted if there
  * is no ongoing animation.
  *
+ * @param[in] obj The object.
  * @param[in] cur_state Current state of the filter
  * @param[in] cur_val Current value
  * @param[in] next_state Next filter state, optional
@@ -98,6 +101,7 @@ EOAPI void efl_gfx_filter_state_set(Eo *obj, const char *cur_state, double cur_v
  * to 1) of that animation timeline. The second state can be omitted if there
  * is no ongoing animation.
  *
+ * @param[in] obj The object.
  * @param[out] cur_state Current state of the filter
  * @param[out] cur_val Current value
  * @param[out] next_state Next filter state, optional
@@ -119,6 +123,7 @@ EOAPI void efl_gfx_filter_state_get(const Eo *obj, const char **cur_state, doubl
  *
  * Gets the padding required to apply this filter.
  *
+ * @param[in] obj The object.
  * @param[out] l Padding on the left
  * @param[out] r Padding on the right
  * @param[out] t Padding on the top
@@ -136,6 +141,7 @@ EOAPI void efl_gfx_filter_padding_get(const Eo *obj, int *l, int *r, int *t, int
  * This will create automatically a new RGBA buffer containing the source
  * object's pixels (as it is rendered).
  *
+ * @param[in] obj The object.
  * @param[in] name Buffer name as used in the program.
  * @param[in] source Object to use as a source of pixels.
  *
@@ -143,7 +149,7 @@ EOAPI void efl_gfx_filter_padding_get(const Eo *obj, int *l, int *r, int *t, int
  *
  * @ingroup Efl_Gfx_Filter
  */
-EOAPI void efl_gfx_filter_source_set(Eo *obj, const char * name, Efl_Gfx *source);
+EOAPI void efl_gfx_filter_source_set(Eo *obj, const char *name, Efl_Gfx_Entity *source);
 
 /**
  * @brief Bind an object to use as a mask or texture in a filter program.
@@ -151,6 +157,7 @@ EOAPI void efl_gfx_filter_source_set(Eo *obj, const char * name, Efl_Gfx *source
  * This will create automatically a new RGBA buffer containing the source
  * object's pixels (as it is rendered).
  *
+ * @param[in] obj The object.
  * @param[in] name Buffer name as used in the program.
  *
  * @return Object to use as a source of pixels.
@@ -159,7 +166,7 @@ EOAPI void efl_gfx_filter_source_set(Eo *obj, const char * name, Efl_Gfx *source
  *
  * @ingroup Efl_Gfx_Filter
  */
-EOAPI Efl_Gfx *efl_gfx_filter_source_get(const Eo *obj, const char * name);
+EOAPI Efl_Gfx_Entity *efl_gfx_filter_source_get(const Eo *obj, const char *name);
 
 /**
  * @brief Extra data used by the filter program.
@@ -171,6 +178,7 @@ EOAPI Efl_Gfx *efl_gfx_filter_source_get(const Eo *obj, const char * name);
  * if the original Lua program contained a line 'name = value'. This can be
  * used to pass in tables.
  *
+ * @param[in] obj The object.
  * @param[in] name Name of the global variable
  * @param[in] value String value to use as data
  * @param[in] execute If @c true, execute 'name = value'
@@ -179,7 +187,7 @@ EOAPI Efl_Gfx *efl_gfx_filter_source_get(const Eo *obj, const char * name);
  *
  * @ingroup Efl_Gfx_Filter
  */
-EOAPI void efl_gfx_filter_data_set(Eo *obj, const char * name, const char *value, Eina_Bool execute);
+EOAPI void efl_gfx_filter_data_set(Eo *obj, const char *name, const char *value, Eina_Bool execute);
 
 /**
  * @brief Extra data used by the filter program.
@@ -191,6 +199,7 @@ EOAPI void efl_gfx_filter_data_set(Eo *obj, const char * name, const char *value
  * if the original Lua program contained a line 'name = value'. This can be
  * used to pass in tables.
  *
+ * @param[in] obj The object.
  * @param[in] name Name of the global variable
  * @param[out] value String value to use as data
  * @param[out] execute If @c true, execute 'name = value'
@@ -199,6 +208,6 @@ EOAPI void efl_gfx_filter_data_set(Eo *obj, const char * name, const char *value
  *
  * @ingroup Efl_Gfx_Filter
  */
-EOAPI void efl_gfx_filter_data_get(const Eo *obj, const char * name, const char **value, Eina_Bool *execute);
+EOAPI void efl_gfx_filter_data_get(const Eo *obj, const char *name, const char **value, Eina_Bool *execute);
 
 #endif
