@@ -11,25 +11,29 @@ typedef Eo Elm_Web;
 #ifndef _ELM_WEB_EO_TYPES
 #define _ELM_WEB_EO_TYPES
 
-/** Types of zoom available.
- *
- * @ingroup Elm_Web
- */
-typedef enum
-{
-  ELM_WEB_ZOOM_MODE_MANUAL = 0, /** Zoom controlled normally by
-                                 * elm_web_zoom_set */
-  ELM_WEB_ZOOM_MODE_AUTO_FIT, /** Zoom until content fits in web object */
-  ELM_WEB_ZOOM_MODE_AUTO_FILL, /** Zoom until content fills web object */
-  ELM_WEB_ZOOM_MODE_LAST /** Sentinel value to indicate end */
-} Elm_Web_Zoom_Mode;
-
 
 #endif
 
+/**
+ * @brief Sets whether to highlight the matched marks.
+ *
+ * If enabled, marks set with @ref elm_web_text_matches_mark will be
+ * highlighted.
+ *
+ * @param[in] obj The object.
+ * @param[in] highlight Whether to highlight the marks or not.
+ *
+ * @return @c true on success, @c false otherwise
+ *
+ * @ingroup Elm_Web
+ */
+EAPI Eina_Bool elm_web_text_matches_highlight_set(Elm_Web *obj, Eina_Bool highlight);
+
 /**
  * @brief Get whether highlighting marks is enabled.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to highlight the marks or not.
  *
  * @ingroup Elm_Web
@@ -37,20 +41,20 @@ typedef enum
 EAPI Eina_Bool elm_web_text_matches_highlight_get(const Elm_Web *obj);
 
 /**
- * @brief Sets whether to highlight the matched marks.
+ * @brief Change useragent of a elm_web object.
  *
- * If enabled, marks set with @ref elm_web_text_matches_mark will be
- * highlighted.
- *
- * @param[in] highlight Whether to highlight the marks or not.
+ * @param[in] obj The object.
+ * @param[in] user_agent String for useragent.
  *
  * @ingroup Elm_Web
  */
-EAPI Eina_Bool elm_web_text_matches_highlight_set(Elm_Web *obj, Eina_Bool highlight);
+EAPI void elm_web_useragent_set(Elm_Web *obj, const char *user_agent);
 
 /**
  * @brief Return current useragent of elm_web object.
  *
+ * @param[in] obj The object.
+ *
  * @return String for useragent.
  *
  * @ingroup Elm_Web
@@ -58,19 +62,27 @@ EAPI Eina_Bool elm_web_text_matches_highlight_set(Elm_Web *obj, Eina_Bool highli
 EAPI const char *elm_web_useragent_get(const Elm_Web *obj);
 
 /**
- * @brief Change useragent of a elm_web object.
+ * @brief Sets the URL for the web object.
  *
- * @param[in] user_agent String for useragent.
+ * It must be a full URL, with resource included, in the form
+ * http://www.enlightenment.org or file:///tmp/something.html
+ *
+ * @param[in] obj The object.
+ * @param[in] url The URL to set.
+ *
+ * @return @c true on success, @c false otherwise
  *
  * @ingroup Elm_Web
  */
-EAPI void elm_web_useragent_set(Elm_Web *obj, const char *user_agent);
+EAPI Eina_Bool elm_web_url_set(Elm_Web *obj, const char *url);
 
 /**
  * @brief Get the current URL for the object.
  *
  * The returned string must not be freed and is guaranteed to be stringshared.
  *
+ * @param[in] obj The object.
+ *
  * @return The URL to set.
  *
  * @ingroup Elm_Web
@@ -78,16 +90,20 @@ EAPI void elm_web_useragent_set(Elm_Web *obj, const char *user_agent);
 EAPI const char *elm_web_url_get(const Elm_Web *obj);
 
 /**
- * @brief Sets the URL for the web object.
+ * @brief Sets the background color to be used by the web object.
  *
- * It must be a full URL, with resource included, in the form
- * http://www.enlightenment.org or file:///tmp/something.html
+ * This is the color that will be used by default when the loaded page does not
+ * set it's own. Color values are pre-multiplied.
  *
- * @param[in] url The URL to set.
+ * @param[in] obj The object.
+ * @param[in] r Red component.
+ * @param[in] g Green component.
+ * @param[in] b Blue component.
+ * @param[in] a Alpha component.
  *
  * @ingroup Elm_Web
  */
-EAPI Eina_Bool elm_web_url_set(Elm_Web *obj, const char *url);
+EAPI void elm_web_bg_color_set(Elm_Web *obj, int r, int g, int b, int a);
 
 /**
  * @brief Get the background color to be used by the web object.
@@ -95,6 +111,7 @@ EAPI Eina_Bool elm_web_url_set(Elm_Web *obj, const char *url);
  * This is the color that will be used by default when the loaded page does not
  * set it's own. Color values are pre-multiplied.
  *
+ * @param[in] obj The object.
  * @param[out] r Red component.
  * @param[out] g Green component.
  * @param[out] b Blue component.
@@ -104,27 +121,6 @@ EAPI Eina_Bool elm_web_url_set(Elm_Web *obj, const char *url);
  */
 EAPI void elm_web_bg_color_get(const Elm_Web *obj, int *r, int *g, int *b, int *a);
 
-/**
- * @brief Sets the background color to be used by the web object.
- *
- * This is the color that will be used by default when the loaded page does not
- * set it's own. Color values are pre-multiplied.
- *
- * @param[in] r Red component.
- * @param[in] g Green component.
- * @param[in] b Blue component.
- * @param[in] a Alpha component.
- *
- * @ingroup Elm_Web
- */
-EAPI void elm_web_bg_color_set(Elm_Web *obj, int r, int g, int b, int a);
-
-/** Get whether Inwin mode is set for the current object.
- *
- * @ingroup Elm_Web
- */
-EAPI Eina_Bool elm_web_inwin_mode_get(const Elm_Web *obj);
-
 /**
  * @brief Sets the default dialogs to use an Inwin instead of a normal window.
  *
@@ -132,20 +128,24 @@ EAPI Eina_Bool elm_web_inwin_mode_get(const Elm_Web *obj);
  * selector will be opened in an Inwin. Otherwise they will use a normal
  * separated window.
  *
- * @param[in] value
+ * @param[in] obj The object.
+ * @param[in] value @c true if dialog will be opened as Inwin, @c false
+ * otherwise
  *
  * @ingroup Elm_Web
  */
 EAPI void elm_web_inwin_mode_set(Elm_Web *obj, Eina_Bool value);
 
 /**
- * @brief Get the status of the tab propagation.
+ * @brief Get whether Inwin mode is set for the current object.
  *
- * @return Whether to propagate Tab keys to Elementary or not.
+ * @param[in] obj The object.
+ *
+ * @return @c true if dialog will be opened as Inwin, @c false otherwise
  *
  * @ingroup Elm_Web
  */
-EAPI Eina_Bool elm_web_tab_propagate_get(const Elm_Web *obj);
+EAPI Eina_Bool elm_web_inwin_mode_get(const Elm_Web *obj);
 
 /**
  * @brief Sets whether to use tab propagation.
@@ -156,95 +156,52 @@ EAPI Eina_Bool elm_web_tab_propagate_get(const Elm_Web *obj);
  * though its internal objects, jumping to the next widget only when that cycle
  * ends.
  *
+ * @param[in] obj The object.
  * @param[in] propagate Whether to propagate Tab keys to Elementary or not.
  *
  * @ingroup Elm_Web
  */
 EAPI void elm_web_tab_propagate_set(Elm_Web *obj, Eina_Bool propagate);
 
+/**
+ * @brief Get the status of the tab propagation.
+ *
+ * @param[in] obj The object.
+ *
+ * @return Whether to propagate Tab keys to Elementary or not.
+ *
+ * @ingroup Elm_Web
+ */
+EAPI Eina_Bool elm_web_tab_propagate_get(const Elm_Web *obj);
+
+/**
+ * @brief Enables or disables the browsing history.
+ *
+ * @param[in] obj The object.
+ * @param[in] enable Whether to enable or disable the browsing history.
+ *
+ * @ingroup Elm_Web
+ */
+EAPI void elm_web_history_enabled_set(Elm_Web *obj, Eina_Bool enable);
+
 /**
  * @brief Get whether browsing history is enabled for the given object.
  *
+ * @param[in] obj The object.
+ *
  * @return Whether to enable or disable the browsing history.
  *
  * @ingroup Elm_Web
  */
 EAPI Eina_Bool elm_web_history_enabled_get(const Elm_Web *obj);
 
-/**
- * @brief Enables or disables the browsing history.
- *
- * @param[in] enable Whether to enable or disable the browsing history.
- *
- * @ingroup Elm_Web
- */
-EAPI void elm_web_history_enabled_set(Elm_Web *obj, Eina_Bool enable);
-
-/**
- * @brief Get the currently set zoom mode.
- *
- * @return The mode to set.
- *
- * @ingroup Elm_Web
- */
-EAPI Elm_Web_Zoom_Mode elm_web_zoom_mode_get(const Elm_Web *obj);
-
-/**
- * @brief Sets the zoom mode to use.
- *
- * The modes can be any of those defined in .Elm_Web_Zoom_Mode, except
- * .ELM_WEB_ZOOM_MODE_LAST. The default is .ELM_WEB_ZOOM_MODE_MANUAL.
- *
- * .ELM_WEB_ZOOM_MODE_MANUAL means the zoom level will be controlled with the
- * @ref elm_web_zoom_set function.
- *
- * .ELM_WEB_ZOOM_MODE_AUTO_FIT will calculate the needed zoom level to make
- * sure the entirety of the web object's contents are shown.
- *
- * .ELM_WEB_ZOOM_MODE_AUTO_FILL will calculate the needed zoom level to fit the
- * contents in the web object's size, without leaving any space unused.
- *
- * @param[in] mode The mode to set.
- *
- * @ingroup Elm_Web
- */
-EAPI void elm_web_zoom_mode_set(Elm_Web *obj, Elm_Web_Zoom_Mode mode);
-
-/**
- * @brief Get the current zoom level set on the web object
- *
- * Note that this is the zoom level set on the web object and not that of the
- * underlying Webkit one. In the .ELM_WEB_ZOOM_MODE_MANUAL mode, the two zoom
- * levels should match, but for the other two modes the Webkit zoom is
- * calculated internally to match the chosen mode without changing the zoom
- * level set for the web object.
- *
- * @return The zoom level to set.
- *
- * @ingroup Elm_Web
- */
-EAPI double elm_web_zoom_get(const Elm_Web *obj);
-
-/**
- * @brief Sets the zoom level of the web object.
- *
- * Zoom level matches the Webkit API, so 1.0 means normal zoom, with higher
- * values meaning zoom in and lower meaning zoom out. This function will only
- * affect the zoom level if the mode set with @ref elm_web_zoom_mode_set is
- * .ELM_WEB_ZOOM_MODE_MANUAL.
- *
- * @param[in] zoom The zoom level to set.
- *
- * @ingroup Elm_Web
- */
-EAPI void elm_web_zoom_set(Elm_Web *obj, double zoom);
-
 /**
  * @brief Sets the function to call when a console message is emitted from JS.
  *
  * This hook will be called when a console message is emitted from JavaScript.
  * There is no default implementation for this feature.
  *
+ * @param[in] obj The object.
  * @param[in] func The callback function to be used.
  * @param[in] data User data.
  *
@@ -260,6 +217,7 @@ EAPI void elm_web_console_message_hook_set(Elm_Web *obj, Elm_Web_Console_Message
  * feature, so leaving this unset or passing @c null in @c func will prevent
  * new windows from opening.
  *
+ * @param[in] obj The object.
  * @param[in] func The hook function to be called when a window is requested.
  * @param[in] data User data.
  *
@@ -274,6 +232,7 @@ EAPI void elm_web_window_create_hook_set(Elm_Web *obj, Elm_Web_Window_Open func,
  * requested. If no function is set or @c null is passed in @c func, the
  * default implementation will take place.
  *
+ * @param[in] obj The object.
  * @param[in] func The callback function to be used.
  * @param[in] data User data.
  *
@@ -288,6 +247,7 @@ EAPI void elm_web_dialog_file_selector_hook_set(Elm_Web *obj, Elm_Web_Dialog_Fil
  * no function is set or @c null is passed in @c func, the default
  * implementation will take place.
  *
+ * @param[in] obj The object.
  * @param[in] func The callback function to be used.
  * @param[in] data User data.
  *
@@ -303,6 +263,7 @@ EAPI void elm_web_dialog_confirm_hook_set(Elm_Web *obj, Elm_Web_Dialog_Confirm f
  * needs to tell the web object which item was selected by calling this
  * function with the index corresponding to the item.
  *
+ * @param[in] obj The object.
  * @param[in] idx The index selected.
  *
  * @ingroup Elm_Web
@@ -316,6 +277,7 @@ EAPI void elm_web_popup_selected_set(Elm_Web *obj, int idx);
  * function is set or @c null is passed in @c func, the default implementation
  * will take place.
  *
+ * @param[in] obj The object.
  * @param[in] func The callback function to be used.
  * @param[in] data User data.
  *
@@ -330,14 +292,20 @@ EAPI void elm_web_dialog_prompt_hook_set(Elm_Web *obj, Elm_Web_Dialog_Prompt fun
  * function is set or @c null is passed in @c func, the default implementation
  * will take place.
  *
- * @param[in] func callback function to be used.
+ * @param[in] obj The object.
+ * @param[in] func Callback function to be used.
  * @param[in] data User data.
  *
  * @ingroup Elm_Web
  */
 EAPI void elm_web_dialog_alert_hook_set(Elm_Web *obj, Elm_Web_Dialog_Alert func, void *data);
 
-/** Queries whether it's possible to go forward in history.
+/**
+ * @brief Queries whether it's possible to go forward in history.
+ *
+ * @param[in] obj The object.
+ *
+ * @return @c true if it is possible to go forward, @c false otherwise
  *
  * @ingroup Elm_Web
  */
@@ -350,6 +318,8 @@ EAPI Eina_Bool elm_web_forward_possible_get(const Elm_Web *obj);
  * cluttering the API with proxy methods we opted to return the internal
  * reference. Be careful using it as it may interfere with elm_web behavior.
  *
+ * @param[in] obj The object.
+ *
  * @return The internal ewk_view object or @c null if it does not exist.
  * (Failure to create or Elementary compiled without ewebkit)
  *
@@ -357,7 +327,12 @@ EAPI Eina_Bool elm_web_forward_possible_get(const Elm_Web *obj);
  */
 EAPI Efl_Canvas_Object *elm_web_webkit_view_get(const Elm_Web *obj);
 
-/** Queries whether it's possible to go back in history.
+/**
+ * @brief Queries whether it's possible to go back in history.
+ *
+ * @param[in] obj The object.
+ *
+ * @return @c true if it is possible to go back, @c false otherwise
  *
  * @ingroup Elm_Web
  */
@@ -370,6 +345,8 @@ EAPI Eina_Bool elm_web_back_possible_get(const Elm_Web *obj);
  * and 1.0. This is an estimated progress accounting for all the frames
  * included in the page.
  *
+ * @param[in] obj The object.
+ *
  * @return A value between 0.0 and 1.0 indicating the progress, or -1.0 on
  * failure.
  *
@@ -382,6 +359,8 @@ EAPI double elm_web_load_progress_get(const Elm_Web *obj);
  *
  * The string returned must be freed by the user when it's done with it.
  *
+ * @param[in] obj The object.
+ *
  * @return A newly allocated string, or @c null if nothing is selected or an
  * error occurred.
  *
@@ -394,12 +373,14 @@ EAPI const char *elm_web_selection_get(const Elm_Web *obj) EINA_WARN_UNUSED_RESU
  *
  * The returned string must not be freed and is guaranteed to be stringshared.
  *
+ * @param[in] obj The object.
+ *
  * @return A stringshared internal string with the current title, or @c null on
  * failure.
  *
  * @ingroup Elm_Web
  */
-EAPI const char *elm_web_title_get(const Elm_Web *obj) EINA_WARN_UNUSED_RESULT;
+EAPI Eina_Stringshare *elm_web_title_get(const Elm_Web *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Jumps the given number of steps in the browsing history.
@@ -407,6 +388,7 @@ EAPI const char *elm_web_title_get(const Elm_Web *obj) EINA_WARN_UNUSED_RESULT;
  * The @c steps value can be a negative integer to back in history, or a
  * positive to move forward.
  *
+ * @param[in] obj The object.
  * @param[in] steps The number of steps to jump.
  *
  * @return @c true on success, @c false on error or if not enough history
@@ -421,6 +403,10 @@ EAPI Eina_Bool elm_web_navigate(Elm_Web *obj, int steps);
  *
  * This is equivalent to calling elm_web_object_navigate(obj, -1);
  *
+ * @param[in] obj The object.
+ *
+ * @return @c true on success, @c false otherwise
+ *
  * @ingroup Elm_Web
  */
 EAPI Eina_Bool elm_web_back(Elm_Web *obj);
@@ -434,11 +420,14 @@ EAPI Eina_Bool elm_web_back(Elm_Web *obj);
  * If an @c unreachable_url is passed it is used as the url for the loaded
  * content. This is typically used to display error pages for a failed load.
  *
+ * @param[in] obj The object.
  * @param[in] html HTML data to load.
  * @param[in] base_url Base URL used for relative paths to external objects
  * (optional).
  * @param[in] unreachable_url URL that could not be reached (optional).
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @since 1.9
  *
  * @ingroup Elm_Web
@@ -448,6 +437,7 @@ EAPI Eina_Bool elm_web_html_string_load(Elm_Web *obj, const char *html, const ch
 /**
  * @brief Searches the given string in a document.
  *
+ * @param[in] obj The object.
  * @param[in] string String to search.
  * @param[in] case_sensitive If search should be case sensitive or not.
  * @param[in] forward If search is from cursor and on or backwards.
@@ -467,6 +457,8 @@ EAPI Eina_Bool elm_web_text_search(const Elm_Web *obj, const char *string, Eina_
  * will later emit an "popup,willdelete" signal to notify the user that any
  * memory and objects related to this popup can be freed.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the menu was successfully destroyed, or @c false if there
  * was no menu to destroy.
  *
@@ -477,6 +469,7 @@ EAPI Eina_Bool elm_web_popup_destroy(Elm_Web *obj);
 /**
  * @brief Shows the given region in the web object.
  *
+ * @param[in] obj The object.
  * @param[in] x The x coordinate of the region to show.
  * @param[in] y The y coordinate of the region to show.
  * @param[in] w The width of the region to show.
@@ -494,6 +487,8 @@ EAPI void elm_web_region_show(Elm_Web *obj, int x, int y, int w, int h);
  * See also @ref elm_web_history_enabled_set,
  * @ref elm_web_forward_possible_get, @ref elm_web_back, @ref elm_web_navigate.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true on success, @c false otherwise.
  *
  * @ingroup Elm_Web
@@ -503,6 +498,7 @@ EAPI Eina_Bool elm_web_forward(Elm_Web *obj);
 /**
  * @brief Marks matches of the given string in a document.
  *
+ * @param[in] obj The object.
  * @param[in] string String to match.
  * @param[in] case_sensitive If match should be case sensitive or not.
  * @param[in] highlight If matches should be highlighted.
@@ -520,6 +516,7 @@ EAPI unsigned int elm_web_text_matches_mark(Elm_Web *obj, const char *string, Ei
  * Like @ref elm_web_region_show, but it animates the scrolling of the object
  * to show the area.
  *
+ * @param[in] obj The object.
  * @param[in] x The x coordinate of the region to show.
  * @param[in] y The y coordinate of the region to show.
  * @param[in] w The width of the region to show.
@@ -536,6 +533,8 @@ EAPI void elm_web_region_bring_in(Elm_Web *obj, int x, int y, int w, int h);
  * "load,error" signal to be emitted, with the is_cancellation flag set to
  * @c true.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true if the cancel was successful, @c false otherwise.
  *
  * @ingroup Elm_Web
@@ -548,6 +547,7 @@ EAPI Eina_Bool elm_web_stop(Elm_Web *obj);
  * The @c steps value can be a negative integer to back in history, or positive
  * to move forward.
  *
+ * @param[in] obj The object.
  * @param[in] steps The number of steps to check for.
  *
  * @return @c true if enough history exists to perform the given jump, @c false
@@ -561,6 +561,8 @@ EAPI Eina_Bool elm_web_navigate_possible_get(Elm_Web *obj, int steps);
  * @brief Requests a reload of the current document, avoiding any existing
  * caches.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true on success, @c false otherwise.
  *
  * @ingroup Elm_Web
@@ -570,6 +572,8 @@ EAPI Eina_Bool elm_web_reload_full(Elm_Web *obj);
 /**
  * @brief Clears all marked matches in the document.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true on success, @c false otherwise.
  *
  * @ingroup Elm_Web
@@ -579,6 +583,8 @@ EAPI Eina_Bool elm_web_text_matches_unmark_all(Elm_Web *obj);
 /**
  * @brief Requests a reload of the current document in the object.
  *
+ * @param[in] obj The object.
+ *
  * @return @c true on success, @c false otherwise.
  *
  * @ingroup Elm_Web
